import Toolbar from '@mui/material/Toolbar'
import IconButton from '@mui/material/IconButton'
import MenuIcon from '@mui/icons-material/Menu';
import SearchIcon from '@mui/icons-material/Search';
import InputBase from '@mui/material/InputBase';
import ArrowBackIcon from '@mui/icons-material/ArrowBack';
import { styled } from '@mui/material/styles';
import { makeStyles } from '@material-ui/core'

const Search = styled('div')(({ theme }:any) => ({
  position: 'relative',
  borderRadius: '20px',
  backgroundColor: '#f1f0f0',
  '&:hover': {
    backgroundColor: '#f5f5f5',
    color:'#2184f7',
  }, 
  marginLeft: 0,
  width: '100%',
  [theme.breakpoints.up('sm')]: {
    marginLeft: theme.spacing(1),
    width: 'auto',
  },
}));

const SearchIconWrapper = styled('div')(({ theme }) => ({
  padding: theme.spacing(0, 2),
  height: '100%',
  position: 'absolute',
  pointerEvents: 'none',
  display: 'flex',
  alignItems: 'center',
  justifyContent: 'center',
}));

const StyledInputBase = styled(InputBase)(({ theme }) => ({
    color: 'inherit',
  '& .MuiInputBase-input': { 
    fontWeight: 500,
    borderRadius: '20px',
    padding: theme.spacing(1, 1, 1, 0),
    paddingLeft: `calc(1em + ${theme.spacing(4)})`,
    transition: theme.transitions.create('width'),
    width: '100%',
    [theme.breakpoints.up('sm')]: {
      width: '35ch',
      '&:focus': {
        outline: '2px solid  #2184f7',
        color: '#2184f7'
      },
    },
  },
}));

const useStyles = makeStyles({
  toolBar: {
    color:'#b1aeae',
  },
  iconBtn: {
    '&:hover': {
      transform: 'rotate(180deg)',
      transition: 'all 250ms ease-out ',
    }
  },
  iconArrow: {
    '&:hover': {
      transform: 'rotate(360deg)',
      transition: 'all 250ms ease-out ',
    }
  },
})

interface ISearchBar {
  handleClick:() => void,
  handleFocus:() => void,
  handleSearch:(e: React.ChangeEvent<HTMLInputElement>) => void,
  isOpen: boolean,
  iMenu: number | null
}

const SearchBar = ({handleClick,handleFocus,handleSearch,isOpen,iMenu}:ISearchBar) => {
  const classes = useStyles()
    return (
        <Toolbar className={classes.toolBar}>
            <IconButton  onClick={handleClick}>
                {isOpen ? <ArrowBackIcon className={classes.iconArrow} /> : <MenuIcon className={classes.iconBtn} />}
            </IconButton>
          <Search>
                <SearchIconWrapper>
                    <SearchIcon />
                </SearchIconWrapper>
                <StyledInputBase
                 onFocus={handleFocus}
                 onChange={handleSearch}
                 placeholder={iMenu === 2 ?'Search contacts':'Search'}
                 inputProps={{ 'aria-label': 'search' }}
                />
            </Search>
        </Toolbar>
    )
}

export default SearchBar